==> electricity_portfolio-0.0.69-py3-none-any.whl: portfolio/portfolio/results_logging/results_logging.py <==
from dataclasses import dataclass, field
from typing import List, Tuple
import numpy as np
import pandas as pd
from matplotlib import pyplot as plt

from portfolio.portfolio.results_logging.plotting import StackPlotConfig
from portfolio.resources.dispatch import DispatchVector


@dataclass
class DispatchLog:
    demand: np.ndarray
    dispatch_log: pd.DataFrame = field(init=False)
    annual_costs: pd.DataFrame = field(init=False)
    total_discharge: float = field(init=False, default=0.0)
    total_cost: float = field(init=False, default=0.0)

    @property
    def levelized_cost(self) -> float:
        return self.total_discharge / self.total_cost

    def __post_init__(self):
        self.clear_log(None)

    def clear_log(self, new_demand: np.ndarray = None):
        if new_demand:
            self.demand = new_demand
        self.dispatch_log = pd.DataFrame.from_dict({
            'demand': self.demand,
            'residual_demand': self.demand
        })

        self.annual_costs = pd.DataFrame(
            index=[
                'annual_dispatch_cost',
                'levelized_cost'
            ]
        )

    def log(
        self,
        dispatch: DispatchVector,
        annual_cost: float = None,
        levelized_cost: float = None
    ):
        self.dispatch_log['residual_demand'] -= dispatch.as_net
        self.dispatch_log[dispatch.discharge_name] = dispatch.discharge
        self.dispatch_log[dispatch.charge_name] = dispatch.charge
        self.total_discharge += dispatch.discharge
        if annual_cost:
            self.total_cost += annual_cost
            self.annual_costs.loc[
                'annual_dispatch_cost',
                dispatch.name
            ] = annual_cost
        if levelized_cost:
            self.annual_costs.loc[
                'levelized_cost',
                dispatch.name
            ] = levelized_cost

    def plot(self, plot_config: StackPlotConfig):
        stack_rank = plot_config.stack_plot_order
        stack_rank.append('residual_demand')
        stack_plt_this = list([self.dispatch_log[r] for r in stack_rank])
        stack_colors = list([plot_config.color_map.get(r, 'red') for r in stack_rank])

        line_rank = plot_config.line_plot_order
        line_plt_this = {r: self.dispatch_log[r] for r in line_rank}
        line_colors = {r: plot_config.color_map.get(r, 'red') for r in line_rank}
        line_plt_this.update({'demand': self.dispatch_log['demand']})
        line_colors.update({'demand': 'black'})

        plt.stackplot(
            self.dispatch_log.index,
            *stack_plt_this,
            labels=stack_rank,
            colors=stack_colors
        )
        for name, data in line_plt_this.items():
            plt.plot(data, label=name, color=line_colors[name])
        plt.legend()
        plt.show()

    def annual_cost_totals(self):
        return pd.Series(data={
            'annual_dispatch_cost': self.total_cost,
            'levelized_cost': self.levelized_cost
        })


@dataclass
class MonteCarloLog:
    scenario: dict
    log: pd.DataFrame = None

    def __post_init__(self):
        self.log = pd.DataFrame()

    def clear_log(self):
        self.log = pd.DataFrame()

    def log_simulation(
        self,
        iteration_result: pd.Series
    ):
        self.log = self.log.append(iteration_result, ignore_index=True)

    def plot(self):
        pass

    def aggregated_statistics(
        self,
        scenario_name: str,
        stats: Tuple[str] = ('mean', 'std')
    ):
        scenario_name_s = pd.Series({'scenario_name': scenario_name})
        scenario_s = pd.Series(self.scenario)
        rows = []
        for stat in stats:
            stat_method = getattr(pd.DataFrame, stat)
            statistic_s = stat_method(self.log)
            stat_label_s = pd.Series({'statistic': stat})
            rows.append(scenario_s.copy().append([scenario_name_s, stat_label_s, statistic_s]))
        return pd.DataFrame(rows)


@dataclass
class ScenarioLogger:
    log: pd.DataFrame = None

    def __post_init__(self):
        self.clear_log()

    def clear_log(self):
        self.log = pd.DataFrame()

    def log_scenario(self, scenario_results: pd.DataFrame):
        self.log = pd.concat([
            self.log,
            scenario_results
        ], axis=1)

    def plot(self):
        pass

==> electricity_portfolio-0.0.70-py3-none-any.whl: portfolio/portfolio/results_logging/results_logging.py <==
from dataclasses import dataclass, field
from typing import List, Tuple
import numpy as np
import pandas as pd
from matplotlib import pyplot as plt

from portfolio.portfolio.results_logging.plotting import StackPlotConfig
from portfolio.resources.dispatch import DispatchVector


@dataclass
class DispatchLog:
    demand: np.ndarray
    dispatch_log: pd.DataFrame = field(init=False)
    annual_costs: pd.DataFrame = field(init=False)
    total_discharge: float = field(init=False, default=0.0)
    total_cost: float = field(init=False, default=0.0)

    @property
    def levelized_cost(self) -> float:
        return self.total_discharge / self.total_cost

    def __post_init__(self):
        self.clear_log(None)

    def clear_log(self, new_demand: np.ndarray = None):
        if new_demand:
            self.demand = new_demand
        self.dispatch_log = pd.DataFrame.from_dict({
            'demand': self.demand,
            'residual_demand': self.demand
        })

        self.annual_costs = pd.DataFrame(
            index=[
                'annual_dispatch_cost',
                'levelized_cost'
            ]
        )

    def log(
        self,
        dispatch: DispatchVector,
        annual_cost: float = None,
        levelized_cost: float = None
    ):
        self.dispatch_log['residual_demand'] -= dispatch.as_net
        self.dispatch_log[dispatch.discharge_name] = dispatch.discharge
        self.dispatch_log[dispatch.charge_name] = dispatch.charge
        self.total_discharge += dispatch.discharge.sum()
        if annual_cost:
            self.total_cost += annual_cost
            self.annual_costs.loc[
                'annual_dispatch_cost',
                dispatch.name
            ] = annual_cost
        if levelized_cost:
            self.annual_costs.loc[
                'levelized_cost',
                dispatch.name
            ] = levelized_cost

    def plot(self, plot_config: StackPlotConfig):
        stack_rank = plot_config.stack_plot_order
        stack_rank.append('residual_demand')
        stack_plt_this = list([self.dispatch_log[r] for r in stack_rank])
        stack_colors = list([plot_config.color_map.get(r, 'red') for r in stack_rank])

        line_rank = plot_config.line_plot_order
        line_plt_this = {r: self.dispatch_log[r] for r in line_rank}
        line_colors = {r: plot_config.color_map.get(r, 'red') for r in line_rank}
        line_plt_this.update({'demand': self.dispatch_log['demand']})
        line_colors.update({'demand': 'black'})

        plt.stackplot(
            self.dispatch_log.index,
            *stack_plt_this,
            labels=stack_rank,
            colors=stack_colors
        )
        for name, data in line_plt_this.items():
            plt.plot(data, label=name, color=line_colors[name])
        plt.legend()
        plt.show()

    def annual_cost_totals(self):
        return pd.Series(data={
            'annual_dispatch_cost': self.total_cost,
            'levelized_cost': self.levelized_cost
        })


@dataclass
class MonteCarloLog:
    scenario: dict
    log: pd.DataFrame = None

    def __post_init__(self):
        self.log = pd.DataFrame()

    def clear_log(self):
        self.log = pd.DataFrame()

    def log_simulation(
        self,
        iteration_result: pd.Series
    ):
        self.log = self.log.append(iteration_result, ignore_index=True)

    def plot(self):
        pass

    def aggregated_statistics(
        self,
        scenario_name: str,
        stats: Tuple[str] = ('mean', 'std')
    ):
        scenario_name_s = pd.Series({'scenario_name': scenario_name})
        scenario_s = pd.Series(self.scenario)
        rows = []
        for stat in stats:
            stat_method = getattr(pd.DataFrame, stat)
            statistic_s = stat_method(self.log)
            stat_label_s = pd.Series({'statistic': stat})
            rows.append(scenario_s.copy().append([scenario_name_s, stat_label_s, statistic_s]))
        return pd.DataFrame(rows)


@dataclass
class ScenarioLogger:
    log: pd.DataFrame = None

    def __post_init__(self):
        self.clear_log()

    def clear_log(self):
        self.log = pd.DataFrame()

    def log_scenario(self, scenario_results: pd.DataFrame):
        self.log = pd.concat([
            self.log,
            scenario_results
        ], axis=1)

    def plot(self):
        pass
